OC.L10N.register(
    "core",
    {
    "Please select a file." : "Por favor selecciona un archivo.",
    "File is too big" : "El archivo es demasiado grande.",
    "The selected file is not an image." : "El archivo seleccionado no es una imagen.",
    "The selected file cannot be read." : "El archivo seleccionado no se puede leer.",
    "The file was uploaded" : "El archivo fue cargado",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "El archivo cargado excede el valor establecido en la directiva upload_max_filesize en el archivo php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "El archivo cargado excede el valor especificado de la directiva MAX_FILE_SIZE en la forma de HTML",
    "The file was only partially uploaded" : "El archivo sólo fue cargado parcialmente",
    "No file was uploaded" : "No se cargó el archivo",
    "Missing a temporary folder" : "Falta una carpeta temporal",
    "Could not write file to disk" : "No fue posible escribir a disco",
    "A PHP extension stopped the file upload" : "Una extensión de PHP detuvo la carga del archivo",
    "Invalid file provided" : "Archivo proporcionado inválido",
    "No image or file provided" : "No se especificó un archivo o imagen",
    "Unknown filetype" : "Tipo de archivo desconocido",
    "An error occurred. Please contact your admin." : "Se presentó un error. Por favor contacta a tu adminsitrador. ",
    "Invalid image" : "Imagen inválida",
    "No temporary profile picture available, try again" : "No hay una imagen de perfil temporal disponible, por favor inténtalo de nuevo",
    "No crop data provided" : "No se han proporcionado datos del recorte",
    "No valid crop data provided" : "No se han proporcionado datos válidos del recorte",
    "Crop is not square" : "El recorte no es cuadrado",
    "State token does not match" : "La ficha de estado no corresponde",
    "Invalid app password" : "Contraseña de app inválida",
    "Could not complete login" : "No se pudo completar el inicio de sesión",
    "State token missing" : "No se encontró el token de estado",
    "Your login token is invalid or has expired" : "Su token de inicio de sesión no es válido o ha caducado",
    "This community release of Nextcloud is unsupported and push notifications are limited." : "Esta versión comunitaria de Nextcloud ya no está soportada y las notificaciones push están limitadas.",
    "Login" : "Iniciar sesión",
    "Unsupported email length (>255)" : "Longitud de correo electrónico no soportada (>255)",
    "Password reset is disabled" : "Restablecer contraseña se encuentra deshabilitado",
    "Could not reset password because the token is expired" : "No se puede restablecer la contraseña porque el token de autenticación ha caducado.",
    "Could not reset password because the token is invalid" : "No se puede restablecer la contraseña porque el token de autenticación no es válido.",
    "Password is too long. Maximum allowed length is 469 characters." : "La contraseña es demasiado larga. La longitud máxima permitida es de 469 caracteres.",
    "%s password reset" : "%s restablecer la contraseña",
    "Password reset" : "Restablecer contraseña",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Haz click en el siguiente botón para restablecer tu contraseña. Si no has solicitado restablecer su contraseña, por favor ignora este correo. ",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Haz click en la siguiente liga para restablecer su contraseña. Si no has solicitado restablecer la contraseña, por favor ignora este mensaje. ",
    "Reset your password" : "Restablecer tu contraseña",
    "The given provider is not available" : "El proveedor dado no está disponible",
    "Task not found" : "Tarea no encontrada",
    "Internal error" : "Error interno",
    "Not found" : "No encontrado",
    "Bad request" : "Solicitud inválida",
    "Requested task type does not exist" : "El tipo de tarea solicitada no existe",
    "Necessary language model provider is not available" : "El proveedor de modelo de lenguaje necesario no está disponible",
    "No text to image provider is available" : "No hay proveedores de texto a imagen disponibles",
    "Image not found" : "Imagen no encontrada",
    "No translation provider available" : "No hay proveedores de traducción disponibles",
    "Could not detect language" : "No se pudo detectar el idioma",
    "Unable to translate" : "No se puede traducir",
    "Nextcloud Server" : "Servidor Nextcloud",
    "Some of your link shares have been removed" : "Se han eliminado algunos de sus enlaces compartidos",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Debido a un error de seguridad, tuvimos que eliminar algunos de sus enlaces compartidos. Por favor vea el enlace para más información.",
    "The account limit of this instance is reached." : "Se alcanzó el límite de usuarios de esta instancia.",
    "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Ingrese su clave de suscripción en la aplicación de soporte para aumentar el límite de cuentas. Esto también le otorga todos los beneficios adicionales que ofrece Nextcloud Enterprise y que es altamente recomendado para la operación en empresas.",
    "Learn more ↗" : "Más información ↗",
    "Preparing update" : "Preparando actualización",
    "[%d / %d]: %s" : "[%d / %d]: %s ",
    "Repair step:" : "Paso de reparación:",
    "Repair info:" : "Información de reparación:",
    "Repair warning:" : "Advertencia de reparación:",
    "Repair error:" : "Error de reparación: ",
    "Please use the command line updater because updating via browser is disabled in your config.php." : "Por favor, utilice el actualizador desde la línea de comandos porque la actualización a través del navegador está deshabilitada en config.php.",
    "Turned on maintenance mode" : "Modo mantenimiento activado",
    "Turned off maintenance mode" : "Modo mantenimiento desactivado",
    "Maintenance mode is kept active" : "El modo mantenimiento sigue activo",
    "Updating database schema" : "Actualizando esquema de base de datos",
    "Updated database" : "Base de datos actualizada",
    "Update app \"%s\" from App Store" : "Actualizar la aplicación \"%s\" desde la App Store",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Verificando si el esquema de la base de datos para %s puede ser actualizado (esto puede tomar mucho tiempo dependiendo del tamaño de la base de datos)",
    "Updated \"%1$s\" to %2$s" : "\"%1$s\" actualizado a %2$s",
    "Set log level to debug" : "Establecer nivel de bitacora a depurar",
    "Reset log level" : "Restablecer nivel de bitácora",
    "Starting code integrity check" : "Comenzando verificación de integridad del código",
    "Finished code integrity check" : "Terminó la verificación de integridad del código ",
    "%s (incompatible)" : "%s (incompatible)",
    "The following apps have been disabled: %s" : "Las siguientes aplicaciones han sido deshabilitadas: %s",
    "Already up to date" : "Ya está actualizado",
    "Error occurred while checking server setup" : "Se presentó un error al verificar la configuración del servidor",
    "For more details see the {linkstart}documentation ↗{linkend}." : "Para más detalles, consulte la {linkstart}documentación ↗{linkend}.",
    "unknown text" : "texto desconocido",
    "Hello world!" : "¡Hola mundo!",
    "sunny" : "soleado",
    "Hello {name}, the weather is {weather}" : "Hola {name}, el clima es {weather}",
    "Hello {name}" : "Hola {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Estos son los resultados de tu búsqueda <script>alert(1)</script></strong>",
    "new" : "nuevo",
    "_download %n file_::_download %n files_" : ["Descargar %n archivos","Descargar %n archivos","Descargar %n archivos"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "La actualización está en curso, abandonar esta página puede interrumpir el proceso en algunos ambientes. ",
    "Update to {version}" : "Actualizar a {version}",
    "An error occurred." : "Se presentó un error.",
    "Please reload the page." : "Por favor vuelve a cargar la página.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "La actualización no fue exitosa. Para más información <a href=\"{url}\">consulta nuestro comentario  en el foro </a> que cubre este tema. ",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "La actualización no fue exitosa. Por favor reporta este tema a la <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Comunidad Nextcloud</a>.",
    "Continue to {productName}" : "Continuar a {productName}",
    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["La actualización fue exitosa. Redireccionando a {productName} en %n segundo.","La actualización fue exitosa. Redireccionando a {productName} en %n segundos.","La actualización fue exitosa. Redireccionando a {productName} en %n segundos."],
    "Applications menu" : "Menú de aplicaciones",
    "Apps" : "Aplicaciones",
    "More apps" : "Más aplicaciones",
    "_{count} notification_::_{count} notifications_" : ["{count} notificación","{count} notificaciones","{count} notificaciones"],
    "No" : "No",
    "Yes" : "Sí",
    "The remote URL must include the user." : "La URL remota debe incluir el usuario.",
    "Invalid remote URL." : "URL remota inválida.",
    "Failed to add the public link to your Nextcloud" : "Se presentó una falla al agregar la liga pública a tu Nextcloud",
    "Federated user" : "Usuario federado",
    "user@your-nextcloud.org" : "usuario@su-nextcloud.org",
    "Create share" : "Crear recurso compartido",
    "Direct link copied to clipboard" : "Enlace directo copiado al portapapeles",
    "Please copy the link manually:" : "Por favor, copie el enlace manualmente:",
    "Custom date range" : "Rango de fechas personalizado",
    "Pick start date" : "Elegir una fecha de inicio",
    "Pick end date" : "Elegir una fecha final",
    "Search in date range" : "Buscar en un rango de fechas",
    "Search in current app" : "Buscar en la aplicación actual",
    "Clear search" : "Limpiar búsqueda",
    "Search everywhere" : "Buscar en todas partes",
    "Searching …" : "Buscando  …",
    "Start typing to search" : "Empiece a escribir para buscar",
    "No matching results" : "No se encontraron coincidencias",
    "Today" : "Hoy",
    "Last 7 days" : "Últimos 7 días",
    "Last 30 days" : "Últimos 30 días",
    "This year" : "Este año",
    "Last year" : "Año pasado",
    "Unified search" : "Búsqueda unificada",
    "Search apps, files, tags, messages" : "Buscar en aplicaciones, archivos, etiquetas, mensajes",
    "Places" : "Lugares",
    "Date" : "Fecha",
    "Search people" : "Buscar personas",
    "People" : "Personas",
    "Filter in current view" : "Filtrar en la vista actual",
    "Results" : "Resultados",
    "Load more results" : "Cargar más resultados",
    "Search in" : "Buscar en",
    "Log in" : "Ingresar",
    "Logging in …" : "Iniciando sesión ...",
    "Log in to {productName}" : "Iniciar sesión en {productName}",
    "Wrong login or password." : "Nombre de usuario o contraseña equivocado. ",
    "This account is disabled" : "Esta cuenta está deshabilitada",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Hemos detectado múltiples intentos de inicio de sesión desde tu IP. Por lo tanto tu siguiente incio de sesión se retrasará hasta 30 segundos. ",
    "Account name or email" : "Nombre de cuenta o correo electrónico",
    "Account name" : "Nombre de cuenta",
    "Server side authentication failed!" : "¡Falló la autenticación del lado del servidor!",
    "Please contact your administrator." : "Por favor contacta al administrador.",
    "Temporary error" : "Error temporal",
    "Please try again." : "Por favor, inténtelo de nuevo",
    "An internal error occurred." : "Se presentó un error interno.",
    "Please try again or contact your administrator." : "Por favor vuelve a intentarlo o contacta a tu adminsitrador. ",
    "Password" : "Contraseña",
    "Log in with a device" : "Iniciar sesión con dispositivo",
    "Login or email" : "Nombre de usuario o correo electrónico",
    "Your account is not setup for passwordless login." : "Tu cuenta no está configurada para iniciar sesión sin contraseña",
    "Your connection is not secure" : "Tu conexión no es segura",
    "Passwordless authentication is only available over a secure connection." : "La autenticación sin contraseña solo está disponible bajo una conexión segura.",
    "Browser not supported" : "Navegador no compatible",
    "Passwordless authentication is not supported in your browser." : "La autenticación sin contraseña no está soportada en tu navegador.",
    "Reset password" : "Restablecer contraseña",
    "Back to login" : "Regresar al inicio de sesión",
    "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "Si la cuenta existe, se ha enviado un mensaje para reestablecer la contraseña a su dirección de correo. Si no lo recibe, verifique su dirección de correo y/o usuario, compruebe sus carpetas de correo basura o solicite ayuda a su administración.",
    "Couldn't send reset email. Please contact your administrator." : "No fue posible enviar el correo de restauración. Por favor contacta a tu adminsitrador. ",
    "Password cannot be changed. Please contact your administrator." : "La contraseña no puede ser cambiada. Por favor, contacte con su administrador.",
    "New password" : "Nueva contraseña",
    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Sus archivos están encriptados. No habrá forma de recuperar sus datos después de restablecer su contraseña. Si no está seguro de qué hacer, contacte a su administrador antes de continuar. ¿Realmente desea continuar?",
    "I know what I'm doing" : "Sé lo que estoy haciendo",
    "Resetting password" : "Reestableciendo contraseña",
    "Schedule work & meetings, synced with all your devices." : "Agenda de trabajo y reuniones, sincronizada con todos tus dispositivos.",
    "Keep your colleagues and friends in one place without leaking their private info." : "Mantén a tus compañeros y amigos en un solo lugar sin filtrar su información privada.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Aplicación de correo electrónico simple bien integrada con Archivos, Contactos y Calendario.",
    "Chatting, video calls, screen sharing, online meetings and web conferencing – in your browser and with mobile apps." : "Mensajes, videollamadas, compartir pantalla, reuniones en línea y conferencias web – en su navegador y aplicaciones móviles.",
    "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Documentos colaborativos, hojas de cálculo y presentaciones, creados en Collabora Online.",
    "Distraction free note taking app." : "Aplicación de notas sin distracciones.",
    "Recommended apps" : "Aplicaciones recomendadas",
    "Loading apps …" : "Cargando aplicaciones ...",
    "Could not fetch list of apps from the App Store." : "No es posible obtener la lista de aplicaciones de la App Store.",
    "App download or installation failed" : "Error al descargar o instalar la aplicación",
    "Cannot install this app because it is not compatible" : "No se puede instalar esta aplicación porque no es compatible",
    "Cannot install this app" : "No se puede instalar esta aplicación",
    "Skip" : "Saltar",
    "Installing apps …" : "Instalando aplicaciones ...",
    "Install recommended apps" : "Instalar las aplicaciones recomendadas",
    "Avatar of {displayName}" : "Avatar de {displayName}",
    "Settings menu" : "Menú de Configuraciones",
    "Loading your contacts …" : "Cargando sus contactos ... ",
    "Looking for {term} …" : "Buscando {term} ...",
    "Search contacts" : "Buscar contactos",
    "Reset search" : "Reestablecer búsqueda",
    "Search contacts …" : "Buscar contactos ...",
    "Could not load your contacts" : "No fue posible cargar tus contactos",
    "No contacts found" : "No se encontraron contactos",
    "Show all contacts" : "Mostrar todos los contactos",
    "Install the Contacts app" : "Instalar la aplicación Contactos",
    "Search" : "Buscar",
    "No results for {query}" : "No hay resultados para {query}",
    "Press Enter to start searching" : "Presione Enter para comenzar a buscar",
    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Por favor, ingrese {minSearchLength} caracter o más para buscar","Por favor, ingrese {minSearchLength} caracteres o más para buscar","Por favor, ingrese {minSearchLength} caracteres o más para buscar"],
    "An error occurred while searching for {type}" : "Ocurrió un error mientras se buscaba {type}",
    "Search starts once you start typing and results may be reached with the arrow keys" : "La búsqueda empieza una vez que comienza a escribir y los resultados pueden seleccionarse con las teclas direccionales",
    "Search for {name} only" : "Buscar sólo por {name}",
    "Loading more results …" : "Cargando más resultados ...",
    "Forgot password?" : "¿Olvidaste tu contraseña?",
    "Back to login form" : "Regresar al inicio de sesión",
    "Back" : "Atrás",
    "Login form is disabled." : "La página de inicio de sesión está deshabilitada.",
    "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "El formulario de inicio de sesión de Nextcloud está deshabilitado. Use otro medio de inicio de sesión disponible o contacte a su administración.",
    "More actions" : "Más acciones",
    "Security warning" : "Advertencia de seguridad",
    "Storage & database" : "Almacenamiento & base de datos",
    "Data folder" : "Carpeta de datos",
    "Install and activate additional PHP modules to choose other database types." : "Instala y activa módulos adicionales de PHP para seleccionar otros tipos de bases de datos. ",
    "For more details check out the documentation." : "Por favor consulta la documentación para más detalles. ",
    "Performance warning" : "Advertencia de desempeño",
    "You chose SQLite as database." : "Eligió SQLite como base de datos.",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite sólo debe usarse para instancias mínimas y de desarrollo. Para producción, recomendamos un motor de base de datos diferente.",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Si usas clientes para sincronizar archivos, el uso de SQLite se desaconseja encarecidamente.",
    "Database user" : "Usuario de la base de datos",
    "Database password" : "Contraseña de la base de datos",
    "Database name" : "Nombre de la base de datos",
    "Database tablespace" : "Espacio de tablas en la base de datos",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Por favor especifica el número de puerto así como el nombre del servidor (ejem., localhost:5432).",
    "Database host" : "Servidor de base de datos",
    "Installing …" : "Instalando ...",
    "Install" : "Instalar",
    "Need help?" : "¿Necesitas ayuda?",
    "See the documentation" : "Ver la documentación",
    "{name} version {version} and above" : "{name} versión {version} y superior",
    "This browser is not supported" : "Este navegador no está soportado",
    "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Su navegador no está soportado. Por favor actualícelo a una versión más nueva o una soportada.",
    "Continue with this unsupported browser" : "Continuar con este navegador no soportado",
    "Supported versions" : "Versiones soportadas",
    "Search {types} …" : "Buscar {types} ...",
    "Choose {file}" : "Elegir {file}",
    "Choose" : "Seleccionar",
    "Copy to {target}" : "Copiar a {target}",
    "Copy" : "Copiar",
    "Move to {target}" : "Mover a {target}",
    "Move" : "Mover",
    "OK" : "OK",
    "read-only" : "sólo-lectura",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} conflicto de archivo","{count} conflictos en el archivo","{count} conflictos en el archivo"],
    "One file conflict" : "Un conflicto en el archivo",
    "New Files" : "Archivos Nuevos",
    "Already existing files" : "Archivos ya existentes",
    "Which files do you want to keep?" : "¿Cuáles archivos deseas mantener?",
    "If you select both versions, the copied file will have a number added to its name." : "Si seleccionas ambas versiones, se le agregará un número al nombre del archivo copiado.",
    "Cancel" : "Cancelar",
    "Continue" : "Continuar",
    "(all selected)" : "(todos seleccionados)",
    "({count} selected)" : "({count} seleccionados)",
    "Error loading file exists template" : "Se presentó un error al cargar la plantilla de existe archivo ",
    "Saving …" : "Guardando ...",
    "seconds ago" : "hace segundos",
    "Connection to server lost" : "Se ha perdido la conexión con el servidor",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Se presentó un error al cargar la página, recargando en %n segundo","Se presentó un error al cargar la página, recargando en %n segundos","Se presentó un error al cargar la página, recargando en %n segundos"],
    "Add to a project" : "Añadir a un proyecto",
    "Show details" : "Mostrar detalles",
    "Hide details" : "Ocultar detalles",
    "Rename project" : "Renombrar proyecto",
    "Failed to rename the project" : "No se pudo renombrar el proyecto",
    "Failed to create a project" : "No se pudo crear el proyecto",
    "Failed to add the item to the project" : "No se pudo añadir el elemento al proyecto",
    "Connect items to a project to make them easier to find" : "Conecte elementos a un proyecto para que sean más fáciles de encontrar",
    "Type to search for existing projects" : "Escriba para buscar proyectos existentes",
    "New in" : "Nuevo en",
    "View changelog" : "Ver el registro de cambios",
    "No action available" : "No hay acciones disponibles",
    "Error fetching contact actions" : "Se presentó un error al traer las acciónes de contatos",
    "Close \"{dialogTitle}\" dialog" : "Cerrar diálogo \"{dialogTitle}\"",
    "Email length is at max (255)" : "La longitud de correo electrónico está en su límite (255)",
    "Non-existing tag #{tag}" : "Etiqueta #{tag} no-existente",
    "Restricted" : "Restringido",
    "Invisible" : "Invisible",
    "Delete" : "Borrar",
    "Rename" : "Renombrar",
    "Collaborative tags" : "Etiquetas colaborativas",
    "No tags found" : "No se encontraron etiquetas",
    "Clipboard not available, please copy manually" : "Portapapeles no disponible, por favor copie manualmente",
    "Personal" : "Personal",
    "Accounts" : "Cuentas",
    "Admin" : "Administración",
    "Help" : "Ayuda",
    "Access forbidden" : "Acceso prohibido",
    "Page not found" : "Página no encontrada",
    "The page could not be found on the server or you may not be allowed to view it." : "No se pudo encontrar la página en el servidor o es posible que no se le permita verla.",
    "Back to %s" : "Volver a %s",
    "Too many requests" : "Demasiadas solicitudes",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Hubieron demasiadas solicitudes desde su red. Vuelva a intentarlo más tarde o contacte a su administrador si se trata de un error.",
    "Error" : "Error",
    "Internal Server Error" : "Error interno del servidor",
    "The server was unable to complete your request." : "El servidor no pudo completar tu solicitud.",
    "If this happens again, please send the technical details below to the server administrator." : "Si esto vuelve a suceder, por favor envia los detalles tecnicos siguientes al adminsitrador del sistema.",
    "More details can be found in the server log." : "Puedes consultar más detalles en la bitácora del servidor. ",
    "For more details see the documentation ↗." : "Para más detalles vea la documentación ↗.",
    "Technical details" : "Detalles técnicos",
    "Remote Address: %s" : "Dirección Remota: %s",
    "Request ID: %s" : "ID de solicitud: %s",
    "Type: %s" : "Tipo: %s",
    "Code: %s" : "Código: %s",
    "Message: %s" : "Mensaje: %s",
    "File: %s" : "Archivo: %s",
    "Line: %s" : "Línea: %s",
    "Trace" : "Rastrear",
    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Parece que está intentando reinstalar Nextcloud. Sin embargo, falta el archivo CAN_INSTALL en el directorio de configuración. Por favor, cree el archivo CAN_INSTALL en la carpeta de configuración para continuar.",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "No se pudo eliminar CAN_INSTALL de la carpeta de configuración. Por favor, elimine este archivo manualmente.",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Esta aplicación requiere de JavaScript para su correcta operación. Por favor {linkstart}habilita JavaScript{linkend} y vuelve a cargar la página. ",
    "Skip to main content" : "Saltar al contenido principal",
    "Skip to navigation of app" : "Saltar a la navegación de la aplicación",
    "Go to %s" : "Ir a %s",
    "Get your own free account" : "Obtenga su propia cuenta gratuita",
    "Connect to your account" : "Conectate a tu cuenta",
    "Please log in before granting %1$s access to your %2$s account." : "Por favor, inicia sesión antes de conceder a %1$s acceso a tu cuenta %2$s.",
    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Si no está intentando configurar un nuevo dispositivo o aplicación, alguien está tratando de engañarlo para que le otorgue acceso a sus datos. En este caso, no continúe y, en su lugar, contacte a su administrador del sistema.",
    "App password" : "Contraseña de la aplicación",
    "Grant access" : "Conceder acceso",
    "Alternative log in using app password" : "Inicio de sesión alternativo usando la contraseña de la aplicación",
    "Account access" : "Acceo de cuenta",
    "Currently logged in as %1$s (%2$s)." : "Actualmente está conectado como %1$s (%2$s).",
    "You are about to grant %1$s access to your %2$s account." : "Está a punto de conceder a %1$s acceso a su cuenta %2$s.",
    "Account connected" : "Cuenta conectada",
    "Your client should now be connected!" : "¡Su cliente ahora debería estar conectado ahora!",
    "You can close this window." : "Puede cerrar esta ventana.",
    "Previous" : "Previo",
    "This share is password-protected" : "Este elemento compartido está protegido con contraseña",
    "The password is wrong or expired. Please try again or request a new one." : "La contraseña es incorrecta o ha caducado. Por favor, inténtelo de nuevo o solicite una nueva.",
    "Please type in your email address to request a temporary password" : "Por favor, ingrese su dirección de correo electrónico para solicitar una contraseña temporal",
    "Email address" : "Dirección de correo electrónico",
    "Password sent!" : "¡Contraseña enviada!",
    "You are not authorized to request a password for this share" : "No está autorizado para solicitar una contraseña para este recurso compartido",
    "Two-factor authentication" : "Autenticación de dos-factores",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "La seguridad mejorada está habilitada para su cuenta. Elija una segunda forma de autentificación:",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "No se pudo cargar al menos uno de sus métodos de autentificación de dos factores. Por favor, contacte a su administrador.",
    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "La autentificación de dos factores es obligatoria pero no se ha configurado en su cuenta. Contacte a su administrador para obtener ayuda.",
    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "La autentificación de dos factores es obligatoria pero no se ha configurado en su cuenta. Por favor, continúe para configurar la autentificación de dos factores.",
    "Set up two-factor authentication" : "Configurar la autentificación de dos pasos",
    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "La autenticación en dos pasos es obligatoria pero no se ha configurado en su cuenta. Use uno de sus códigos de respaldo para iniciar sesión o comuníquese con su administrador para obtener ayuda.",
    "Use backup code" : "Usar código de respaldo",
    "Cancel login" : "Cancelar inicio de sesión",
    "Enhanced security is enforced for your account. Choose which provider to set up:" : "Se debe cumplir la seguridad mejorada para su cuenta. Elija qué proveedor configurar:",
    "Error while validating your second factor" : "Se presentó un error al validar tu segundo factor",
    "Access through untrusted domain" : "Accesa a través de un dominio no de confianza",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Por favor contacta a tu adminsitrador. Si tu eres un administrador, edita la propiedad \"trusted_domains\" en el archivo config/config.php como en el ejemplo config.sample.php.",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Más información sobre cómo configurar esto se puede encontrar en la %1$sdocumentación%2$s.",
    "App update required" : "Se requiere una actualización de la aplicación",
    "%1$s will be updated to version %2$s" : "%1$s se actualizará a la versión %2$s",
    "The following apps will be updated:" : "Se actualizarán las siguientes aplicaciones:",
    "These incompatible apps will be disabled:" : "Las siguientes aplicaciones incompatibles serán deshabilitadas:",
    "The theme %s has been disabled." : "El tema %s ha sido deshabilitado. ",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Por favor asegurarte de que la base de datos, la carpeta de configuración y las carpetas de datos hayan sido respaldadas antes de continuar. ",
    "Start update" : "Iniciar actualización",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Para evitar la expiración de tiempo en instalaciones grandes, puedes ejecutar el siguiente comando desde tu directorio de instalación:",
    "Detailed logs" : "Bitácoras detalladas",
    "Update needed" : "Se requiere de una actualización",
    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Por favor, use el actualizador desde la línea de comandos ya que tiene una gran instancia con más de 50 cuentas.",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Para más ayuda, por favor consulta la <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentación</a>.",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Estoy conciente de que si continúo haciendo la actualización vía web, la interfaz de usuario corre el riesgo de que el tiempo de la solicitud expire y cause pérdida de datos, pero cuento con un respaldo y sé como restaurar mi instancia en caso de una falla. ",
    "Upgrade via web on my own risk" : "Actualizar vía Web bajo mi propio riesgo",
    "Maintenance mode" : "Modo de mantenimiento",
    "This %s instance is currently in maintenance mode, which may take a while." : "Esta instancia %s se encuentra actualmente en modo mantenimiento, que podría tomar algo de tiempo. ",
    "This page will refresh itself when the instance is available again." : "Esta página se actualizará automáticamente cuando la instancia esté disponible nuevamente.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Contacta a tu administrador del sistema si este mensaje persiste o se presentó de manera inesperada.",
    "Currently open" : "Actualmente abierto",
    "Login with username or email" : "Iniciar sesión con nombre de usuario o correo electrónico",
    "Login with username" : "Iniciar sesión con nombre de usuario",
    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Mensajes, videollamadas, compartir pantalla, reuniones en línea y conferencias web – en su navegador y aplicaciones móviles.",
    "You have not added any info yet" : "Aún no has añadido información",
    "{user} has not added any info yet" : "{user} aún no añade información",
    "Error opening the user status modal, try hard refreshing the page" : "Error al abrir la ventana de estado del usuario, intente actualizar la página",
    "Edit Profile" : "Editar perfil",
    "The headline and about sections will show up here" : "El encabezado y la sección Acerca de aparecerán aquí",
    "Error loading message template: {error}" : "Se presentó un error al cargar la plantilla del mensaje: {error}",
    "Very weak password" : "Contraseña muy débil",
    "Weak password" : "Contraseña débil",
    "So-so password" : "Contraseña aceptable",
    "Good password" : "Buena contraseña",
    "Strong password" : "Contraseña fuerte",
    "Profile not found" : "Perfil no encontrado",
    "The profile does not exist." : "El perfil no existe.",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Tu directorio de datos y sus archivos probablemente sean accesibles desde Internet ya que el archivo .htaccess no funciona.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Para más información de como configurar correctaemente tu servidor, por favor consulta la <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentación</a>.",
    "Show password" : "Mostrar contraseña",
    "Toggle password visibility" : "Alternar visibilidad de la contraseña",
    "Configure the database" : "Configurar la base de datos",
    "Only %s is available." : "Sólo %s está disponible.",
    "Database account" : "Cuenta de la base de datos"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
